#
# spec file for package qpwgraph
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qpwgraph
Version:        0.7.2
Release:        1.1
Summary:        PipeWire Graph Qt GUI Interface
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
URL:            https://gitlab.freedesktop.org/rncbc/qpwgraph
Source:         https://gitlab.freedesktop.org/rncbc/qpwgraph/-/archive/v%{version}/qpwgraph-v%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Linguist)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(libpipewire-0.3)

%description
qpwgraph is a graph manager dedicated for PipeWire, using the
Qt C++ framework, based and pretty much like the same of QjackCtl.

%prep
%setup -q -n %{name}-v%{version}

%build
%cmake_qt6 \
  -DCONFIG_ALSA_MIDI=ON
%qt6_build

%install
%qt6_install

%files
%license LICENSE.md
%doc ChangeLog README.md
%{_bindir}/%{name}
%{_datadir}/applications/org.rncbc.%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/org.rncbc.%{name}.*
%{_datadir}/icons/hicolor/*/mimetypes/org.rncbc.%{name}*.*
%{_datadir}/metainfo/org.rncbc.%{name}.metainfo.xml
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/mime/packages/org.rncbc.%{name}.xml

%changelog
* Sat May 25 2024 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.7.2:
  * Remove margins and spacing from the top-level canvas layout.
  * Possible fix to pipewire backend thread loop locking.
  * Update to latest framework level (Qt >= 6.7).
* Sat Apr 27 2024 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.7.1:
  * Hot-fix: Disable thumbview interactivity: prevent dragging
    nodes over to extremely severe off-limits by accident.
* Wed Apr 24 2024 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.7.0:
  * Whether to show the System-tray informational and/or active
    Patchbay warning messages, respectively on Close and/or Quit,
    is now optional (cf. Help > Enable System Tray Message and/or
    Help > Enable Patchbay Message, resp.)
  * Introduce the View/Thumbview option as a whole graph thumbnail
    overview helper.
* Sat Apr  6 2024 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.6.3:
  * Node and port title ellipsis shortning trimmed and simplified.
  * Fix system-tray icon to a 32x32 pixmap.
  * Fix renamed ports positioned incorrectly after relaunch.
* Sun Jan 28 2024 ecsos <ecsos@opensuse.org>
- Update to version 0.6.2:
  * Make the main canvas background to mid-gray, when on non-dark
    color themes.
  * Updated copyright headers into the New Year (2024).
* Tue Dec  5 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.6.1:
  * Introduce Help > Enable ALSA MIDI runtime option, now
    permitting to disable the ALSA MIDI/Sequencer graph conveniency
    on a whim.
  * Disconnect all pinned connections when patchbay is deactivated,
    subject to Patchbay > Auto Disconnect option.
  * Fix a potential port duplication when recycled under the same
    node and reusing a previous port id.
  * Don't unpin connections that are manually disconnected, when
    patchbay is deactivated and auto-pin is off.
* Wed Nov  8 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.6.0:
  * Improve Patchbay / Exclusive mode scan enforcement.
  * Hopefully fix the hideous random crashes caused by very short
    lived nodes, recycled by reusing the very same ids.
  * Cope with nodes that can possibly remain with the very same
    name but different ids.
  * Add deactivated (-d, --deactivated) and non-exclusive patchbay
    (-n, --nonexclusive) command line options.
  * Fix unique/single instance support (Qt >= 6.6).
* Sun Oct 29 2023 Dirk Müller <dmueller@suse.com>
- update to 0.5.3:
  * Added user contributed documentation: How To Use The
    Patchbay.
  * Fix condition for saving node name aliases.
  * Ctrl+left or middle-button click-dragging for panning, is now
    a lot smoother, hopefully.
  * Click-dragging with the mouse middle-button is for panning
    only, not to start a selection anymore.
  * Add Ctrl+Q to Quit action
* Mon Jul 17 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.5.1:
  * Fix segfault on initialisation that was affecting Qt5 builds.
* Sun Jul 16 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.5.0:
  * Completely refactored the internal PipeWire node registry
    logic, just to have unique node names, as seen fit to purpose
    to solve an old undefined behaviour to positioning and Patchbay
    persistence of multiple nodes with the very same and exact
    name.
  * Fix the main PipeWire registry thread-safety, into a two-level
    critical section, hopefully preventing the race-conditions that
    are the suspected cause to some rare crashes.
* Mon Jul 10 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.4.5:
  * Split non-physical terminal device nodes for monitor and
    control ports, adding the suffix "[Monitor]" and/or "[Control]"
    resp. to the node name.
  * Fix the dimming of new connections when Patchbay/Edit mode is
    on and Patchbay/Auto Pin is off.
* Sun Jun 18 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.4.4 (changes since 0.4.2):
  * Split devices for capture/monitor and playback ports.
* Sun Apr  2 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.4.2:
  * Soft incremental bounds constraints now imposed to all new and
    old nodes positioning.
  * Attempt to auto-start minimised to system-tray icon, if
    enabled, when restoring a desktop session (eg. after logout,
    shutdown or restart).
* Fri Mar  3 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.4.1 (changes since 0.3.9):
  * Node names now have the "media.name" property as a bracketed
    suffix; when given and applicable.
  * Node icons now reflecting their proper application/theme icons
    or else, a bland and generic default taken from the
    "client.api" property (eg. "pw", "jack" or "pulse").
  * Introducing touch pinch-gesture for zooming.
  * Attempt to make port labels as short as possible.
  * Fix a possible crash when several PW objects (nodes and ports)
    are created and destroyed in fast succession.
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 0.3.9:
  * Whether to draw connectors through or around nodes is now an
  user preference option (cf. View > Connect Through Nodes).
* Sat Nov 19 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.3.8:
  * Allow middle mouse button for grabbing and dragging the canvas.
* Sat Oct 22 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.3.7:
  * Fix the system-tray icon tooltip to always reflect current
    main window title, usually the current patchbay name.
  * Make up visual immediate feedback connections.
* Sat Sep 24 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.3.6:
  * View / Repel Overlapping Nodes option added.
* Thu Sep 15 2022 Christophe Giboudeaux <christophe@krop.fr>
- Use the Qt6 build macros to fix the Leap 15.4 build
* Sat Aug 20 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.3.5:
  * Patchbay/Scan menu command removed as redundant.
  * Added Patchbay/Auto Pin connections option.
  * Add current system user-name to the singleton/unique
    application instance identifier.
* Sat Jul  9 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.3.4:
  * Fix repainting of pinned/unpinned connections when switching
    patchbay profiles and Patchbay/Edit mode is on.
* Wed Jul  6 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.3.3:
  * Patchbay/Edit mode introduced: pinning and unpinning
    connections to and from current patchbay is now implemented.
  * Original Graph/Connect and Disconnect keyboard shortcuts, [Ins]
    and [Del], are now added to the existing ones, respectively.
* Mon Jun 13 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.3.2:
  * Fix initial nodes layout positioning, now back to the former
    spiraled away from the centre.
* Sun May 29 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.3.1:
  * Only ask to quit an activated patchbay when actually quitting
    the application (not just closing a patchbay).
  * Graph/Connect and Disconnect keyboard shortcuts changed from
    [Ins] and [Del], to [Ctrl+C] and [Ctrl+D] respectively; also
    added [F2] as brand new keyboard shortcut for Edit/Rename...
* Wed May 25 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.3.0:
  * Fix document dirtiness (modified state) when making connections
    and/or disconnections on a clear and new patchbay.
  * Attempt to save and possibly restore different node positions
    and aliases when forner original node name is non-unique.
* Thu Apr 28 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.2.6:
  * Patchbay now treats multiple nodes and respective ports with
    the same name as one, applying the same rule.
* Sun Apr 10 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.2.5:
  * Prevent an graph refresh or update as much as possible while in
    some canvas editing business.
  * Possibly fix a random segfault when rendering connection lines
    ahead of time.
* Sat Mar 19 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.2.4:
  * Whether to enable the system-tray icon option has been added to
    main menu (cf. Help > System Tray Icon).
  * Allow the Patchbay toolbar to also have a vertical orientation,
    on the left and right areas of the main window.
  * Add a barebones man page to the install procedure.
  * Add amissing file code to desktop exec entry.
* Sat Mar 12 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.2.3:
  * Add a start minimised (-m, --minimized) command line option.
  * The main application icon is now presented in a scalable format
    (SVG).
* Wed Mar  2 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Initial package.
